/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.scripting.jruby.monitor;

import org.glassfish.api.statistics.impl.CountStatisticImpl;
import org.glassfish.gmbal.Description;
import org.glassfish.gmbal.ManagedAttribute;
import org.glassfish.gmbal.ManagedObject;
import org.glassfish.probe.provider.annotations.ProbeListener;
import org.glassfish.probe.provider.annotations.ProbeParam;

import java.util.Collection;
import java.util.Collections;
import java.util.concurrent.ConcurrentHashMap;
import java.util.logging.Logger;


/**
 * @author Vivek Pandey
 */
@ManagedObject
@Description("JRuby Container Statistics")
public class JRubyProbeStatsProvider {

    private final CountStatisticImpl activeRubyAppsCount = new CountStatisticImpl("Active Ruby applications", "count", "Number of currently loaded Ruby applications");
    private final ConcurrentHashMap<String, RubyApplicationData> apps = new ConcurrentHashMap<String, RubyApplicationData>();
    private final Logger logger = Logger.getLogger(JRubyProbeStatsProvider.class.getName());

    @ProbeListener("glassfish:jruby:jruby-container:jrubyModuleStartedEvent")
    public void rubyAppLoadEvent(
            @ProbeParam("appName") String appName,
            @ProbeParam("applicationType") String applicationType,
            @ProbeParam("environment") String environment,
            @ProbeParam("jrubyVersion") String jrubyVersion
            ){
        //appName can't be null
        if(appName == null){
            logger.warning("appName is null in jrubyModuleStartedEvent! Looks like the event is not triggered properly, ignoring this monitoring event.");
            return;
        }
        activeRubyAppsCount.increment();
        apps.put(appName, new RubyApplicationData(appName, applicationType, environment, jrubyVersion));
    }

    @ProbeListener("glassfish:jruby:jruby-container:jrubyModuleStoppedEvent")
    public void rubyAppUnloadEvent(
            @ProbeParam("appName") String appName,
            @ProbeParam("applicationType") String applicationType,
            @ProbeParam("environment") String environment
            ){
        if(appName == null){
            logger.warning("appName is null in jrubyModuleStartedEvent! Looks like the event is not triggered properly, ignoring this monitoring event.");
            return;
        }
        activeRubyAppsCount.decrement();
        apps.remove(appName);
    }

    @ManagedAttribute
    @Description("Number of active Ruby applications")
    public long getActiveRubyAppsAcount() {
        return activeRubyAppsCount.getCount();
    }

    @ManagedAttribute
    @Description("Active Ruby applications deployed on GlassFish")
    public Collection<RubyApplicationData> getRubyApplications(){
        return Collections.unmodifiableCollection(apps.values());
    }

    /*package*/ RubyApplicationData getApplication(String appName){
        return apps.get(appName);
    }
            
}
