/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.scripting.jruby.monitor;

import org.glassfish.gmbal.Description;
import org.glassfish.gmbal.ManagedAttribute;
import org.glassfish.gmbal.ManagedData;

import java.util.concurrent.atomic.AtomicInteger;

/**
 * @author Vivek Pandey
 */
@ManagedData
@Description("JRuby runtime pool stats")
public class JRubyRuntimePool {
    private final AtomicInteger hardMinimum = new AtomicInteger(Integer.MIN_VALUE);
    private final AtomicInteger hardMaximum = new AtomicInteger(Integer.MIN_VALUE);
    private final AtomicInteger activeRuntimes = new AtomicInteger(Integer.MIN_VALUE);
    private final AtomicInteger queueSize = new AtomicInteger(Integer.MIN_VALUE);
    private final AtomicInteger queueUpThreshold = new AtomicInteger(Integer.MIN_VALUE);
    private final AtomicInteger queueDownThreshold = new AtomicInteger(Integer.MIN_VALUE);
    private final AtomicInteger newThreshold = new AtomicInteger(Integer.MIN_VALUE);

    private JRubyRuntimePool(Builder builder) {
        this.hardMinimum.set(builder.hardMinimum);
        this.hardMaximum.set(builder.hardMaximum);
        this.activeRuntimes.set(builder.activeRuntimes);
        this.queueSize.set(builder.queueSize);
        this.queueUpThreshold.set(builder.queueUpThreshold);
        this.queueDownThreshold.set(builder.queueDownThreshold);
        this.newThreshold.set(builder.newThreshold);
    }

    @ManagedAttribute
    @Description("Minimum runtimes active")
    public int getHardMinimum() {
        return hardMinimum.get();
    }

    @ManagedAttribute
    @Description("Maximum runtimes active")
    public int getHardMaximum() {
        return hardMaximum.get();
    }

    @ManagedAttribute
    @Description("Currently active runtimes")
    public int getActiveRuntimes() {
        return activeRuntimes.get();
    }

    @ManagedAttribute
    @Description("Maximum idle runtimes")
    public int getQueueSize() {
        return queueSize.get();
    }

    @ManagedAttribute
    @Description("How eager the pool is to increase the maximum idle runtimes")
    public int getQueueUpThreshold() {
        return queueUpThreshold.get();
    }

    @ManagedAttribute
    @Description("How eager the pool is to decrease the currently active runtimes")
    public int getQueueDownThreshold() {
        return queueDownThreshold.get();
    }

    @ManagedAttribute
    @Description("How eager the pool is to increase the currently active runtimes")    
    public int getNewThreshold() {
        return newThreshold.get();
    }

    public static class Builder {
        private int hardMinimum;
        private int hardMaximum;
        private int activeRuntimes;
        private int queueSize;
        private int queueUpThreshold;
        private int queueDownThreshold;
        private int newThreshold;

        public Builder(int hardMinimum, int hardMaximum) {
            this.hardMinimum = hardMinimum;
            this.hardMaximum = hardMaximum;
        }

        public Builder activeRuntimes(int value) {
            this.activeRuntimes = value;
            return this;
        }

        public Builder queueSize(int value) {
            this.queueSize = value;
            return this;
        }

        public Builder queueUpThreshold(int value) {
            this.queueUpThreshold = value;
            return this;
        }

        public Builder queueDownThreshold(int value) {
            this.queueDownThreshold = value;
            return this;
        }

        public Builder newThreshold(int value) {
            this.newThreshold = value;
            return this;
        }

        public JRubyRuntimePool build() {
            return new JRubyRuntimePool(this);
        }
    }

    /*package*/ void update(Builder builder){
        activeRuntimes.set(builder.activeRuntimes);
        queueSize.set(builder.queueSize);
        queueUpThreshold.set(builder.queueUpThreshold);
        queueDownThreshold.set(builder.queueDownThreshold);
        newThreshold.set(builder.newThreshold);
    }
}
