/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.scripting.jruby.monitor;

import org.glassfish.probe.provider.annotations.Probe;
import org.glassfish.probe.provider.annotations.ProbeParam;
import org.glassfish.probe.provider.annotations.ProbeProvider;

/**
 * @author Vivek Pandey
 */
@ProbeProvider(moduleProviderName = "glassfish", moduleName = "jruby", probeProviderName="runtime-pool")
public class JRubyRuntimePoolProvider {

    /**
     * JRuby runtime pool.
     *
     * @param hardMinimum        Minimum runtimes active
     * @param hardMaximum        Maximum runtimes active
     * @param activeRuntimes     Currently active runtimes
     * @param queueSize          Maximum idle runtimes
     * @param queueUpThreshold   How eager the pool is to increase the maximum idle runtimes
     * @param queueDownThreshold How eager the pool is to decrease the currently active runtimes
     * @param newThreshold       How eager the pool is to increase the currently active runtimes
     */

    @Probe(name = "runtimePoolStartEvent")
    public void runtimePoolStartEvent(
            @ProbeParam("appName") String appName,
            @ProbeParam("hardMinimum") int hardMinimum,
            @ProbeParam("hardMaximum") int hardMaximum,
            @ProbeParam("activeRuntimes") int activeRuntimes,
            @ProbeParam("queueSize") int queueSize,
            @ProbeParam("queueUpThreshold") int queueUpThreshold,
            @ProbeParam("queueDownThreshold") int queueDownThreshold,
            @ProbeParam("newThreshold") int newThreshold
    ) {
    }


    /**
     * Runtime pool update event
     *
     * @param activeRuntimes     Currently active runtimes
     * @param queueSize          Maximum idle runtimes
     * @param queueUpThreshold   How eager the pool is to increase the maximum idle runtimes
     * @param queueDownThreshold How eager the pool is to decrease the currently active runtimes
     * @param newThreshold       How eager the pool is to increase the currently active runtimes
     */
    @Probe(name="runtimePoolUpdateEvent")
    public void runtimePoolUpdateEvent(
            @ProbeParam("appName") String appName,
            @ProbeParam("activeRuntimes") int activeRuntimes,
            @ProbeParam("queueSize") int queueSize,
            @ProbeParam("queueUpThreshold") int queueUpThreshold,
            @ProbeParam("queueDownThreshold") int queueDownThreshold,
            @ProbeParam("newThreshold") int newThreshold
    ){

    }

}
