/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 * 
 * Copyright 1997-2007 Sun Microsystems, Inc. All rights reserved.
 * 
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License. You can obtain
 * a copy of the License at https://glassfish.dev.java.net/public/CDDL+GPL.html
 * or glassfish/bootstrap/legal/LICENSE.txt.  See the License for the specific
 * language governing permissions and limitations under the License.
 * 
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/bootstrap/legal/LICENSE.txt.
 * Sun designates this particular file as subject to the "Classpath" exception
 * as provided by Sun in the GPL Version 2 section of the License file that
 * accompanied this code.  If applicable, add the following below the License
 * Header, with the fields enclosed by brackets [] replaced by your own
 * identifying information: "Portions Copyrighted [year]
 * [name of copyright owner]"
 * 
 * Contributor(s):
 * 
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package org.glassfish.scripting.jruby.monitor;

import org.glassfish.gmbal.Description;
import org.glassfish.gmbal.ManagedAttribute;
import org.glassfish.gmbal.ManagedObject;
import org.glassfish.probe.provider.annotations.ProbeListener;
import org.glassfish.probe.provider.annotations.ProbeParam;

import java.util.logging.Logger;

/**
 * JRuby runtime pool stats. It is per application.
 * @author Vivek Pandey
 */
@ManagedObject
@Description("JRuby runtime pool monitoring data")
public class JRubyRuntimePoolStatsProvider {

    private final Logger logger = Logger.getLogger(JRubyRuntimePoolStatsProvider.class.getName());

    private final String appName;
    private final String contextPath;
    private JRubyRuntimePool runtimePool;

    public JRubyRuntimePoolStatsProvider(String appName, String contextPath) {
        this.appName = appName;
        this.contextPath = contextPath;
    }

    @ManagedAttribute
    @Description("Application name")
    public String getApplicationName(){
        return appName;
    }


    @ManagedAttribute
    @Description("Application context-path")
    public String getContextPath(){
        return contextPath;
    }

    @ManagedAttribute
    @Description("JRuby runtime pool map per application")
    public JRubyRuntimePool getJRubyRuntimePool(){
        return runtimePool;
    }

    @ProbeListener("glassfish:jruby:runtime-pool:runtimePoolStartEvent")
    @Description("JRuby runtime pool creation Event")
    public void runtimePoolStartedEvent(
            @ProbeParam("appName") String appName,
            @ProbeParam("hardMinimum") int hardMinimum,
            @ProbeParam("hardMaximum") int hardMaximum,
            @ProbeParam("activeRuntimes") int activeRuntimes,
            @ProbeParam("queueSize") int queueSize,
            @ProbeParam("queueUpThreshold") int queueUpThreshold,
            @ProbeParam("queueDownThreshold") int queueDownThreshold,
            @ProbeParam("newThreshold") int newThreshold
    ){
        if(appName == null){
            logger.warning("appName is null in runtimePoolStartedEvent! Looks like the event is not triggered properly, ignoring this monitoring event.");
            return;
        }
        runtimePool = new JRubyRuntimePool.Builder(hardMinimum, hardMaximum).
                activeRuntimes(activeRuntimes).
                queueSize(queueSize).
                queueUpThreshold(queueUpThreshold).
                queueDownThreshold(queueDownThreshold).
                newThreshold(newThreshold).build();
    }

    @ProbeListener("glassfish:jruby:runtime-pool:runtimePoolUpdateEvent")    
    @Description("JRuby runtime pool update Event")
    public void runtimePoolUpdatedEvent(
            @ProbeParam("appName") String appName,
            @ProbeParam("activeRuntimes") int activeRuntimes,
            @ProbeParam("queueSize") int queueSize,
            @ProbeParam("queueUpThreshold") int queueUpThreshold,
            @ProbeParam("queueDownThreshold") int queueDownThreshold,
            @ProbeParam("newThreshold") int newThreshold
    ){
        if(appName == null){
            logger.warning("appName is null in runtimePoolUpdatedEvent! Looks like the event is not triggered properly, ignoring this monitoring event.");
            return;
        }

        JRubyRuntimePool.Builder builder = new JRubyRuntimePool.Builder(runtimePool.getHardMinimum(), runtimePool.getHardMaximum()).
                activeRuntimes(activeRuntimes).
                queueSize(queueSize).
                queueUpThreshold(queueUpThreshold).
                queueDownThreshold(queueDownThreshold).
                newThreshold(newThreshold);

        runtimePool.update(builder);
    }
}
